@@ -14,11 +14,10 @@ int main()
 
     kp::Manager mgr;
 
-    auto tensorInA = mgr.buildTensor({ 2.0, 4.0, 6.0 });
-    auto tensorInB = mgr.buildTensor({ 0.0, 1.0, 2.0 });
-    auto tensorOut = mgr.buildTensor({ 0.0, 0.0, 0.0 });
+    auto tensorInA = mgr.tensor({ 2.0, 4.0, 6.0 });
+    auto tensorInB = mgr.tensor({ 0.0, 1.0, 2.0 });
+    auto tensorOut = mgr.tensor({ 0.0, 0.0, 0.0 });
 
-#ifdef KOMPUTE_ANDROID_SHADER_FROM_STRING
     std::string shader(R"(
         // The version to use 
         #version 450
@@ -38,23 +37,19 @@ int main()
         }
       )");
 
-    mgr.evalOpDefault<kp::OpAlgoBase>(
-            { tensorInA, tensorInB, tensorOut },
-            std::vector<char>(shader.begin(), shader.end()));
-#else
-    mgr.evalOpDefault<kp::OpAlgoBase>(
-            { tensorInA, tensorInB, tensorOut },
-            std::vector<char>(
-            kp::shader_data::shaders_glsl_opmult_comp_spv,
-            kp::shader_data::shaders_glsl_opmult_comp_spv
-                + kp::shader_data::shaders_glsl_opmult_comp_spv_len));
-#endif
+    std::vector<std::shared_ptr<kp::Tensor>> params = { tensorInA, tensorInB, tensorOut };
 
-    mgr.evalOpDefault<kp::OpTensorSyncLocal>({tensorOut});
+    std::shared_ptr<kp::Algorithm> algo = mgr.algorithm(params, kp::Shader::compileSource(shader));
+
+    mgr.sequence()
+        ->record<kp::OpTensorSyncDevice>(params)
+        ->record<kp::OpAlgoDispatch>(algo)
+        ->record<kp::OpTensorSyncLocal>(params)
+        ->eval();
 
     // prints "Output {  0  4  12  }"
     std::cout<< "Output: {  ";
-    for (const float& elem : tensorOut->data()) {
+    for (const float& elem : tensorOut->vector()) {
       std::cout << elem << "  ";
     }
     std::cout << "}" << std::endl;
