@@ -1,16 +1,16 @@
 #pragma once
-#include "kompute/Core.hpp"
 #include "kompute/shaders/shaderopmult.hpp"
 #include "kompute/shaders/shaderlogisticregression.hpp"
-#include "kompute/Manager.hpp"
-#include "kompute/Sequence.hpp"
+#include "kompute/Core.hpp"
+#include "kompute/Shader.hpp"
+#include "kompute/Tensor.hpp"
+#include "kompute/Algorithm.hpp"
 #include "kompute/operations/OpBase.hpp"
-#include "kompute/operations/OpAlgoBase.hpp"
-#include "kompute/operations/OpAlgoLhsRhsOut.hpp"
-#include "kompute/operations/OpMult.hpp"
-#include "kompute/operations/OpTensorCreate.hpp"
+#include "kompute/operations/OpMemoryBarrier.hpp"
 #include "kompute/operations/OpTensorCopy.hpp"
 #include "kompute/operations/OpTensorSyncDevice.hpp"
 #include "kompute/operations/OpTensorSyncLocal.hpp"
-#include "kompute/Algorithm.hpp"
-#include "kompute/Tensor.hpp"
+#include "kompute/operations/OpAlgoDispatch.hpp"
+#include "kompute/operations/OpMult.hpp"
+#include "kompute/Sequence.hpp"
+#include "kompute/Manager.hpp"
